@@ -1,6 +1,7 @@
 
 import os
 import platform
+from datetime import datetime
 
 if(platform.system()=='Windows'):
     print('Windows系统')
@@ -34,4 +35,7 @@ stk_uiverse = { "sz380":'000009.SH',  # 上证380
                 "sz300":'399007.SZ',  # 深圳300
                 "zx300":'399008.SZ',  # 中小300
                 "hs300":'399300.SZ',  # 沪深300
-                "zzall":'399985.SZ'}  # 中证全指
\ No newline at end of file
+                "zzall":'399985.SZ'}  # 中证全指
+
+defualt_start_date = 20070104
+defualt_end_date = int(datetime.now().strftime("%Y%m%d"))
\ No newline at end of file
