@@ -48,17 +48,19 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     """ Intensive time sereis data with trade day as index """
 
     tidx = 'trade_dt'
-    def get_daily_data(self,datapath,instruments,fields,start_date,end_date):
+    def get_daily_data(self,datapath,instruments,fields,start_date,end_date,freq = "Tdays",tidx = None):
         if isinstance(instruments,str):
             instruments = [instruments]
         path = os.path.join(datapath,'merged.h5')
-        start_index,end_index = Tdcal.locate_index(start_date,end_date,freq = 'Tdays')
-        return read_mergeh5(path,instruments,fields,start_index,end_index,self.tidx)
+        start_index,end_index = Tdcal.locate_index(start_date,end_date,freq = freq)
+        if tidx is None:
+            tidx = self.tidx # 判断是否使用默认的tidx
+        return read_mergeh5(path,instruments,fields,start_index,end_index,tidx)
     
     def get_sparse_daily_data(self,datapath,instruments,**kws):
         if isinstance(instruments,str):
             instruments = [instruments]
-        tidx = kws.get("tidx",self.tidx)
+        tidx = kws.get("tidx",self.tidx)            # 判断是否使用默认的tidx
         defualt_si,defualt_ei = 0,1e7
         path = os.path.join(datapath,'merged.h5')
         fields = kws.get("fields",None)
@@ -77,7 +79,7 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
 
     @print_func_time
     def get_daily_share_deridi(self,instruments,fields,start_date,end_date):
-        return self.get_daily_data(ashare_derivative_indicator,instruments,fields,start_date,end_date)
+        return self.get_daily_data(ashare_derivative_indicator,instruments,fields,start_date,end_date,freq = "Adays",tidx="ann_date") # derivative 是Adays
 
     @print_func_time
     def get_daily_share_l2idi(self,instruments,fields,start_date,end_date):
