@@ -21,6 +21,7 @@ ashare_idu_cs = os.path.join(data_path,r"AShareIndustriesClass_CS")
 ashare_idu_gics =os.path.join(data_path,r"AShareIndustriesClass_GICS")
 ashare_idu_sw = os.path.join(data_path,r'AShareIndustriesClass_SW')
 ashare_idu_wind = os.path.join(data_path,r'AShareIndustriesClass_WIND')
+ashare_idu_code = os.path.join(data_path,r'AShareIndustriesCode')
 
 class BaseStatusInfoProvider(abc.ABC):
 
@@ -92,7 +93,7 @@ class LocalInstStatusProvider(BaseStatusInfoProvider):
         else:
             univ = stk_uiverse.get(univ)
             IdxSP = LocalIndexStatusProvider()
-            return IdxSP.index_member(univ,start_date,end_date)
+            return IdxSP.index_member(univ,start_date,end_date).set_index("stockcode")
 
     @print_func_time
     def ashare_ipodate(self,stkcode,fields = None):
@@ -121,7 +122,7 @@ class LocalIndustryMemberProvider:
         path = os.path.join(datapath,'all.h5')
         df = pd.read_hdf(path,'data')
         if level:
-            df = df[level]
+            df = df[[level, "entry_date", "remove_date"]]
         if stockcode:
             df = df.loc[stockcode]
         return df
@@ -145,3 +146,7 @@ class LocalIndustryMemberProvider:
     @print_func_time
     def Industrycompo_wind(self,stockcode = None,level = None):
         return self.get_indexmember(ashare_idu_wind,stockcode,level)
+    
+    @print_func_time
+    def Industrycodes(self):
+        return pd.read_hdf(os.path.join(ashare_idu_code,"all.h5"),"data")
